Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Peer ¶
type Peer struct {
UserData []byte
// contains filtered or unexported fields
}
Peer maintains information about a peer discovered on the network. Because the struct may be used from multiple goroutines, all access to members must be done through accessors that lock a mutex.
Click to show internal directories.
Click to hide internal directories.